@@ -51,7 +51,6 @@ static GtkTargetEntry target_table[] = {
 static guint n_targets = sizeof (target_table) / sizeof (target_table[0]);
 
 static GtkContainerClass *parent_class = NULL;
-extern char **environ;
 
 struct _QuickBoxPrivate {
 	GtkWidget         *arrow_up;
@@ -892,26 +891,6 @@ quick_box_class_init (QuickBoxClass    *class)
 }
 
 
-static char **
-get_environment ()
-{
-	int    i;
-	char **retval = NULL;
-
-	for (i = 0; environ [i] != NULL; i++)
-		;
-	
-	retval = g_new (char *, i + 2);
-	
-	for (i = 0; environ [i]; i++) 
-		retval [i] = g_strdup (environ [i]);
-	
-	retval [i++] = NULL;
-
-	return retval;
-}
-
-
 static gboolean
 item_activated (QuickButton *button)
 {
@@ -920,15 +899,12 @@ item_activated (QuickButton *button)
 	ditem = g_object_get_data (G_OBJECT (button), "ditem");
 	if (ditem != NULL) {
 		GError  *error = NULL;
-		char   **envp = NULL;
-		
-		envp = get_environment ();
-		gnome_desktop_item_launch_with_env (ditem, 
-						    NULL, 
-						    0, 
-						    envp, 
-						    &error);
-		g_strfreev (envp);
+
+		gnome_desktop_item_launch_on_screen (ditem, 
+						     NULL,
+						     0,
+						     gtk_widget_get_screen (GTK_WIDGET (button)),
+						     -1, &error);
 
 		if (error != NULL)
 			_gtk_error_dialog_from_gerror_run (NULL, &error);
@@ -1003,6 +979,8 @@ button_button_press_cb (GtkWidget      *button,
 		return FALSE;
 
 	popup_menu = gtk_menu_new ();
+	gtk_menu_set_screen (GTK_MENU (popup_menu),
+			     gtk_widget_get_screen (button));
 
 	if (quick_box->priv->popup_menu != NULL)
 		g_signal_connect_swapped (G_OBJECT (popup_menu),
